@@ -20,7 +20,8 @@ from djangoDeployGitHook import views
 
 urlpatterns = [
     path('test_githook', views.test_githook, name='test_githook'),
-    path('githookA2Hosting', views.githookA2Hosting, name='githookA2Hosting'),
+    path('githookA2HostingClone', views.githookA2HostingCloneUpdate, name='githookA2HostingClone'),
+    path('githookA2HostingRemote', views.githookA2HostingRemoteUpdate, name='githookA2HostingRemote'),
     path('githookRaspberry', views.githookRaspberry, name='githookRaspberry'),
 
     path('test_update', views.test_update, name='test_update'),
