@@ -95,6 +95,8 @@ def githookA2HostingRemoteUpdate(request):
         # Deploy some code for example
         import subprocess
         process = subprocess.Popen(['git', 'pull','origin','master'])
+        #git submodule update --recursive --remote -f
+        process = subprocess.Popen(['git', 'submodule','update','-recursive','--remote','-f'])
         import sys
         subprocess.check_call([sys.executable, "-m", "pip", "install", "-r", "requirements.txt"])
 
@@ -171,3 +173,5 @@ def githookRaspberry(request):
 
 def test_update(request):
     return HttpResponse('Hello, From DjangoDeployGitHook!')
+
+
